.. image:: https://github.com/IMIO/imio.prettylink/actions/workflows/main.yml/badge.svg
   :target: https://github.com/IMIO/imio.prettylink/actions/workflows/main.yml

.. image:: https://coveralls.io/repos/IMIO/imio.prettylink/badge.png?branch=master
   :target: https://coveralls.io/r/IMIO/imio.prettylink?branch=master


====================
imio.prettylink
====================

Manage generation of a pretty link to an element including coloration, leading icons, ...
